@@ -1,12 +1,12 @@
 from .mdobject import MDObject
 
 class MDHeading(MDObject):
-    heading = None
-    level = None
-    def __init__(self, heading: str, level: int):
+    heading: str = None
+    level: int = None
+    def __init__(self, heading: str, level: int) -> None:
         self.heading = heading
         self.level = level
-    def __str__(self):
+    def __str__(self) -> str:
         mdstr = '\n'
         for _ in range(self.level):
             mdstr += '#'
@@ -14,5 +14,5 @@ class MDHeading(MDObject):
         mdstr += self.heading
         mdstr += '\n'
         return mdstr
-    def __repr__(self):
-        return f'<MDHeading: {self.heading:s}>'
+    def __repr__(self) -> str:
+        return f'<py2md.MDHeading: {self.heading:s}>'
